[llvm-commits] [llvm] r156245 - in /llvm/trunk: include/llvm/Support/SourceMgr.h lib/Support/SourceMgr.cpp

Chris Lattner sabre at nondot.org
Sat May 5 15:11:05 PDT 2012


Author: lattner
Date: Sat May  5 17:11:04 2012
New Revision: 156245

URL: http://llvm.org/viewvc/llvm-project?rev=156245&view=rev
Log:
revert my patches, which are causing problems.

Modified:
    llvm/trunk/include/llvm/Support/SourceMgr.h
    llvm/trunk/lib/Support/SourceMgr.cpp

Modified: llvm/trunk/include/llvm/Support/SourceMgr.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/Support/SourceMgr.h?rev=156245&r1=156244&r2=156245&view=diff
==============================================================================
--- llvm/trunk/include/llvm/Support/SourceMgr.h (original)
+++ llvm/trunk/include/llvm/Support/SourceMgr.h Sat May  5 17:11:04 2012
@@ -123,14 +123,7 @@
 
   /// FindLineNumber - Find the line number for the specified location in the
   /// specified file.  This is not a fast method.
-  unsigned FindLineNumber(SMLoc Loc, int BufferID = -1) const {
-    return getLineAndColumn(Loc, BufferID).first;
-  }
-
-  /// getLineAndColumn - Find the line and column number for the specified
-  /// location in the specified file.  This is not a fast method.
-  std::pair<unsigned, unsigned>
-    getLineAndColumn(SMLoc Loc, int BufferID = -1) const;
+  unsigned FindLineNumber(SMLoc Loc, int BufferID = -1) const;
 
   /// PrintMessage - Emit a message about the specified location with the
   /// specified string.

Modified: llvm/trunk/lib/Support/SourceMgr.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Support/SourceMgr.cpp?rev=156245&r1=156244&r2=156245&view=diff
==============================================================================
--- llvm/trunk/lib/Support/SourceMgr.cpp (original)
+++ llvm/trunk/lib/Support/SourceMgr.cpp Sat May  5 17:11:04 2012
@@ -79,10 +79,9 @@
   return -1;
 }
 
-/// getLineAndColumn - Find the line and column number for the specified
-/// location in the specified file.  This is not a fast method.
-std::pair<unsigned, unsigned>
-SourceMgr::getLineAndColumn(SMLoc Loc, int BufferID) const {
+/// FindLineNumber - Find the line number for the specified location in the
+/// specified file.  This is not a fast method.
+unsigned SourceMgr::FindLineNumber(SMLoc Loc, int BufferID) const {
   if (BufferID == -1) BufferID = FindBufferContainingLoc(Loc);
   assert(BufferID != -1 && "Invalid Location!");
 
@@ -92,8 +91,7 @@
   // location.
   unsigned LineNo = 1;
 
-  const char *BufStart = Buff->getBufferStart();
-  const char *Ptr = BufStart;
+  const char *Ptr = Buff->getBufferStart();
 
   // If we have a line number cache, and if the query is to a later point in the
   // same file, start searching from the last query location.  This optimizes
@@ -110,6 +108,7 @@
   for (; SMLoc::getFromPointer(Ptr) != Loc; ++Ptr)
     if (*Ptr == '\n') ++LineNo;
 
+
   // Allocate the line number cache if it doesn't exist.
   if (LineNoCache == 0)
     LineNoCache = new LineNoCacheTy();
@@ -119,10 +118,7 @@
   Cache.LastQueryBufferID = BufferID;
   Cache.LastQuery = Ptr;
   Cache.LineNoOfQuery = LineNo;
-  
-  size_t NewlineOffs = StringRef(BufStart, Ptr-BufStart).find_last_of("\n\r");
-  if (NewlineOffs == StringRef::npos) NewlineOffs = ~0ULL;
-  return std::make_pair(LineNo, Ptr-BufStart-NewlineOffs);
+  return LineNo;
 }
 
 void SourceMgr::PrintIncludeStack(SMLoc IncludeLoc, raw_ostream &OS) const {
@@ -157,15 +153,14 @@
 
   // Scan backward to find the start of the line.
   const char *LineStart = Loc.getPointer();
-  const char *BufStart = CurMB->getBufferStart();
-  while (LineStart != BufStart && LineStart[-1] != '\n' &&
-         LineStart[-1] != '\r')
+  while (LineStart != CurMB->getBufferStart() &&
+         LineStart[-1] != '\n' && LineStart[-1] != '\r')
     --LineStart;
 
   // Get the end of the line.
   const char *LineEnd = Loc.getPointer();
-  const char *BufEnd = CurMB->getBufferEnd();
-  while (LineEnd != BufEnd && LineEnd[0] != '\n' && LineEnd[0] != '\r')
+  while (LineEnd != CurMB->getBufferEnd() &&
+         LineEnd[0] != '\n' && LineEnd[0] != '\r')
     ++LineEnd;
   std::string LineStr(LineStart, LineEnd);
 
@@ -191,10 +186,9 @@
                                        R.End.getPointer()-LineStart));
   }
   
-  std::pair<unsigned, unsigned> LineAndCol = getLineAndColumn(Loc, CurBuf);
   return SMDiagnostic(*this, Loc,
-                      CurMB->getBufferIdentifier(), LineAndCol.first,
-                      LineAndCol.second, Kind, Msg.str(),
+                      CurMB->getBufferIdentifier(), FindLineNumber(Loc, CurBuf),
+                      Loc.getPointer()-LineStart, Kind, Msg.str(),
                       LineStr, ColRanges);
 }
 





More information about the llvm-commits mailing list